@@ -72,4 +72,4 @@ class DtoBk:
     user_id: str
     search_type: list  
     connectors: list
-    data: json
\ No newline at end of file
+    data: dict
\ No newline at end of file
